
THREE.WebGLRenderer.prototype.renderPixi = function(stage, renderTarget, forceClear)
{
    // if there is no pixi renderer its time to make one!
    if(!this.pixiRenderer)
    {
        // lets make sure the renderer is the same size as Three.js
        // Importantly we pass a three.js context directly to pixi.
        this.pixiRenderer = new PIXI.WebGLRenderer(this.domElement.width, this.domElement.height, {view:this.domElement, context:this.context});
        
        // lets only clear if the user wants to
        this.pixiRenderer.clearBeforeRender = false;
    }

    
    if(renderTarget)
    {
        this.setRenderTarget(renderTarget);
        
        if( !renderTarget.__pixiRenderTexture)
        {     

            renderTarget.__pixiRenderTexture = PIXI.RenderTexture.create(renderTarget.width , renderTarget.height);

            this.pixiRenderer.bindRenderTexture(renderTarget.__pixiRenderTexture);

            var fbo = renderTarget.__pixiRenderTexture.baseTexture._glRenderTargets[0].frameBuffer;
            
            // here we map the vbo..
            fbo.framebuffer = renderTarget.__webglFramebuffer;
        }
        else
        {
            if(renderTarget.width != renderTarget.__pixiRenderTexture.width 
            && renderTarget.height != renderTarget.__pixiRenderTexture.height)
            {
                renderTarget.__pixiRenderTexture.resize(renderTarget.width, renderTarget.height);
            }
        }
    }

    // reset the pixi state of WebGL
    // this ensures that the state is correct when pixi begins rendering
    this.pixiRenderer.reset();

    if(renderTarget)
    {
        this.pixiRenderer.render(stage, renderTarget.__pixiRenderTexture, forceClear);
    }
    else
    {
        this.pixiRenderer.resize(this.domElement.width, this.domElement.height);
        this.pixiRenderer.render(stage, null, forceClear);
    }

    // reset the WebGL state so that three.js can carry on, business as usual!
    this.resetGLState();
}

